package com.jiuqi.util;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/StringList.class */
public class StringList implements Serializable, Cloneable {
    private static final int DELIMITER_DEFINED = 1;
    private static final int QUOTECHAR_DEFINED = 2;
    private static final int NAMEVALSEP_DEFINED = 4;
    protected List items = new ArrayList();
    protected List objects = null;
    private char delimiter = 0;
    private char quoteChar = 0;
    private char nameValueSeparator = 0;
    private int defined = 0;
    private static final String CS_GB2312 = "GB2312";
    private static final String CS_ISO_8859_1 = "ISO-8859-1";

    protected boolean getDefined(int item) {
        return (this.defined & item) != 0;
    }

    protected void setDefined(int item) {
        this.defined |= item;
    }

    public boolean isEmpty() {
        return this.items.size() == 0;
    }

    public int size() {
        return this.items.size();
    }

    public void clear() {
        this.items.clear();
        if (this.objects != null) {
            this.objects.clear();
        }
    }

    public String get(int index) {
        return (String) this.items.get(index);
    }

    public void set(int index, String newValue) {
        this.items.set(index, newValue);
    }

    public Object getObject(int index) {
        if (this.objects == null) {
            return null;
        }
        return this.objects.get(index);
    }

    public Object getObject(String item) {
        int index;
        if (this.objects != null && (index = indexOf(item)) >= 0) {
            return this.objects.get(index);
        }
        return null;
    }

    public void setObject(int index, Object value) {
        if (value == null && this.objects == null) {
            return;
        }
        if (this.objects == null) {
            this.objects = new ArrayList(size());
            for (int i = 0; i < size(); i++) {
                this.objects.add(null);
            }
        }
        this.objects.set(index, value);
    }

    public void setObject(String item, Object value) {
        int index = indexOf(item);
        if (index < 0) {
            add(item);
            index = size() - 1;
        }
        setObject(index, value);
    }

    public void assign(StringList source) {
        if (source.items == null) {
            if (this.items != null) {
                this.items.clear();
            }
        } else {
            if (this.items == null) {
                this.items = new ArrayList();
            } else {
                this.items.clear();
            }
            this.items.addAll(source.items);
        }
        if (source.objects == null) {
            if (this.objects != null) {
                this.objects.clear();
            }
        } else {
            if (this.objects == null) {
                this.objects = new ArrayList();
            } else {
                this.objects.clear();
            }
            this.objects.addAll(source.objects);
        }
    }

    public void add(String item) {
        this.items.add(item);
        if (this.objects != null) {
            this.objects.add(null);
        }
    }

    public void add(String item, Object data) {
        this.items.add(item);
        if (this.objects != null) {
            this.objects.add(null);
        }
        setObject(this.items.size() - 1, data);
    }

    public void add(int index, String item) {
        this.items.add(index, item);
        if (this.objects != null) {
            this.objects.add(index, null);
        }
    }

    public void remove(int index) {
        this.items.remove(index);
        if (this.objects != null) {
            this.objects.remove(index);
        }
    }

    public void remove(String item) {
        for (int i = this.items.size() - 1; i >= 0; i--) {
            String str = (String) this.items.get(i);
            if (str == item || (str != null && str.equals(item))) {
                this.items.remove(i);
                if (this.objects != null) {
                    this.objects.remove(i);
                    return;
                }
                return;
            }
        }
    }

    public int indexOf(String item) {
        return this.items.indexOf(item);
    }

    public int find(String item) {
        int sb = 0;
        int se = this.items.size() - 1;
        int flag = -1;
        while (true) {
            if (sb <= se) {
                int sp = (sb + se) >> 1;
                flag = compare(item, (String) this.items.get(sp));
                if (flag > 0) {
                    sb = sp + 1;
                } else if (flag < 0) {
                    se = sp - 1;
                } else {
                    sb = sp;
                    break;
                }
            } else {
                break;
            }
        }
        return flag == 0 ? sb : (-sb) - 1;
    }

    public int addsort(String item) {
        int index = find(item);
        if (index < 0) {
            this.items.add((-index) - 1, item);
            if (this.objects != null) {
                this.objects.add((-index) - 1, null);
            }
        }
        return index;
    }

    public int indexOfObject(Object obj) {
        if (this.objects == null) {
            return -1;
        }
        return this.objects.indexOf(obj);
    }

    protected void quicksort(int L, int R) {
        int I;
        do {
            I = L;
            int J = R;
            String zfn = (String) this.items.get((L + R) >> 1);
            while (true) {
                if (compare(zfn, (String) this.items.get(I)) > 0) {
                    I++;
                } else {
                    while (compare(zfn, (String) this.items.get(J)) < 0) {
                        J--;
                    }
                    if (I <= J) {
                        Object T = this.items.get(I);
                        this.items.set(I, this.items.get(J));
                        this.items.set(J, T);
                        if (this.objects != null) {
                            Object T2 = this.objects.get(I);
                            this.objects.set(I, this.objects.get(J));
                            this.objects.set(J, T2);
                        }
                        I++;
                        J--;
                    }
                    if (I > J) {
                        break;
                    }
                }
            }
            if (L < J) {
                quicksort(L, J);
            }
            L = I;
        } while (I < R);
    }

    public void sort() {
        if (this.items.size() > 1) {
            quicksort(0, this.items.size() - 1);
        }
    }

    public String getText() {
        StringBuffer text = new StringBuffer(1024);
        for (int i = 0; i < this.items.size(); i++) {
            text.append(get(i));
            text.append('\n');
        }
        return text.toString();
    }

    public void setText(String newText) {
        StringTokenizer st = new StringTokenizer(newText, "\n");
        this.items.clear();
        while (st.hasMoreTokens()) {
            String s = st.nextToken();
            if (s != null && s.length() > 0 && s.charAt(s.length() - 1) == '\r') {
                s = s.substring(0, s.length() - 1);
            }
            this.items.add(s);
        }
        this.objects = null;
    }

    public String[] toStringArray() {
        if (size() == 0) {
            return null;
        }
        String[] result = new String[size()];
        for (int i = 0; i < size(); i++) {
            result[i] = get(i);
        }
        return result;
    }

    public Object[] toObjectArray() {
        if (size() == 0) {
            return null;
        }
        Object[] result = new Object[size()];
        for (int i = 0; i < size(); i++) {
            result[i] = getObject(i);
        }
        return result;
    }

    public String toString() {
        StringBuffer result = new StringBuffer("[");
        for (int i = 0; i < size(); i++) {
            result.append("(\"" + get(i) + "\", ");
            result.append(getObject(i));
            result.append(StringHelper.rightParenthesis);
            if (i < size() - 1) {
                result.append(", ");
            }
        }
        result.append("]");
        return result.toString();
    }

    public Object clone() {
        StringList result = null;
        try {
            result = (StringList) super.clone();
            result.items = this.items == null ? null : (List) ((ArrayList) this.items).clone();
            result.objects = this.objects == null ? null : (List) ((ArrayList) this.objects).clone();
        } catch (CloneNotSupportedException unused) {
        }
        return result;
    }

    public static int compare(String s1, String s2) {
        if (s1 == null && s2 == null) {
            return 0;
        }
        if (s1 == null) {
            return -1;
        }
        if (s2 == null) {
            return 1;
        }
        try {
            String ns1 = new String(s1.toString().getBytes(CS_GB2312), CS_ISO_8859_1);
            String ns2 = new String(s2.toString().getBytes(CS_GB2312), CS_ISO_8859_1);
            return ns1.compareTo(ns2);
        } catch (Exception unused) {
            return 0;
        }
    }

    public char getDelimiter() {
        if (getDefined(1)) {
            return this.delimiter;
        }
        return ';';
    }

    public void setDelimiter(char value) {
        this.delimiter = value;
        setDefined(1);
    }

    public char getQuoteChar() {
        if (getDefined(2)) {
            return this.quoteChar;
        }
        return '\"';
    }

    public void setQuoteChar(char value) {
        this.quoteChar = value;
        setDefined(2);
    }

    public char getNameValueSeparator() {
        if (getDefined(4)) {
            return this.nameValueSeparator;
        }
        return '=';
    }

    public void setNameValueSeparator(char value) {
        this.nameValueSeparator = value;
        setDefined(4);
    }

    public String getDelimitedText() {
        StringBuffer retText = new StringBuffer();
        int count = size();
        if (count == 1 && StringUtils.isEmpty(get(0))) {
            retText.append(getQuoteChar());
            retText.append(getQuoteChar());
        } else {
            for (int i = 0; i < count; i++) {
                String s = get(i);
                if (s.indexOf(getQuoteChar()) != -1 || s.indexOf(getDelimiter()) != -1) {
                    s = StringUtils.quote(s, getQuoteChar());
                }
                if (i > 0) {
                    retText.append(getDelimiter());
                }
                retText.append(s);
            }
        }
        return retText.toString();
    }

    public void setDelimitedText(String value) {
        clear();
        if (StringUtils.isEmpty(value)) {
            return;
        }
        StringBuffer buffer = new StringBuffer();
        boolean startQuote = false;
        int i = 0;
        while (i < value.length()) {
            int i2 = i;
            i++;
            char curChar = value.charAt(i2);
            if (curChar == getQuoteChar()) {
                if (startQuote) {
                    if (i >= value.length()) {
                        break;
                    }
                    if (value.charAt(i) == getQuoteChar()) {
                        buffer.append(value.charAt(i));
                        i++;
                    } else if (value.charAt(i) == getDelimiter()) {
                        startQuote = false;
                    } else {
                        buffer.append(value.charAt(i));
                        i++;
                    }
                } else if (buffer.length() > 0) {
                    buffer.append(curChar);
                } else {
                    startQuote = true;
                }
            } else if (curChar == getDelimiter()) {
                if (startQuote) {
                    buffer.append(curChar);
                } else {
                    add(buffer.toString());
                    buffer = new StringBuffer();
                    startQuote = false;
                }
            } else {
                buffer.append(curChar);
            }
        }
        add(buffer.toString());
    }

    protected String extractName(String s) {
        int index;
        if (s == null || (index = s.indexOf(getNameValueSeparator())) == -1) {
            return null;
        }
        return s.substring(0, index);
    }

    public String getName(int index) {
        return extractName(get(index));
    }

    public int indexOfName(String name) {
        if (name == null) {
            return -1;
        }
        for (int i = 0; i < size(); i++) {
            if (compare(name, getName(i)) == 0) {
                return i;
            }
        }
        return -1;
    }

    public String getValue(String name) {
        int index = indexOfName(name);
        if (index == -1) {
            return null;
        }
        return get(index).substring(name.length() + 1);
    }

    public void setValue(String name, String value) {
        int index = indexOfName(name);
        if (StringUtils.isEmpty(value)) {
            if (index != -1) {
                remove(index);
            }
        } else if (index == -1) {
            add(String.valueOf(name) + getNameValueSeparator() + value);
        } else {
            set(index, String.valueOf(name) + getNameValueSeparator() + value);
        }
    }

    public String getValue(int index) {
        String name = getName(index);
        if (StringUtils.isEmpty(name)) {
            return get(index);
        }
        return get(index).substring(name.length() + 1);
    }

    public void setValue(int index, String value) {
        if (StringUtils.isEmpty(value)) {
            if (index >= 0) {
                remove(index);
            }
        } else if (index >= 0) {
            set(index, String.valueOf(getName(index)) + getNameValueSeparator() + value);
        } else {
            add(String.valueOf(getNameValueSeparator()) + value);
        }
    }
}
